DefaultRand

Struct DefaultRand 

pub struct DefaultRand { /* private fields */ }
Default random generator which is good for most applications.

This currently uses Xoroshiro128StarStar, but that may be changed in the future (with a major version bump).

Implementations

Source

impl DefaultRand

pub fn initialize_states(seed: u64, num_states: usize) -> Vec<Self>

Available on non-CUDA only.

Initializes many states such that each state is offset in the main sequence by at least 2**64 elements (based on the current default generator). Such that every state is independent from the others as long as no state requests more than 2**64 random numbers.