pub struct Xoshiro128PlusPlus { /* private fields */ }Expand description
A xoshiro128++ random number generator.
The xoshiro128++ algorithm is not suitable for cryptographic purposes, but is very fast and has excellent statistical properties.
The algorithm used here is translated from the xoshiro128plusplus.c
reference source code by
David Blackman and Sebastiano Vigna.
Implementations
Sourceimpl Xoshiro128PlusPlus
impl Xoshiro128PlusPlus
Sourcepub fn jump(&mut self)
pub fn jump(&mut self)
Jump forward, equivalently to 2^64 calls to next_u32().
This can be used to generate 2^64 non-overlapping subsequences for parallel computations.
use rand_xoshiro::rand_core::SeedableRng;
use rand_xoshiro::Xoroshiro128PlusPlus;
let rng1 = Xoroshiro128PlusPlus::seed_from_u64(0);
let mut rng2 = rng1.clone();
rng2.jump();
let mut rng3 = rng2.clone();
rng3.jump();Sourcepub fn long_jump(&mut self)
pub fn long_jump(&mut self)
Jump forward, equivalently to 2^96 calls to next_u32().
This can be used to generate 2^32 starting points, from each of which
jump() will generate 2^32 non-overlapping subsequences for parallel
distributed computations.
Sourcepub fn initialize_states(seed: u64, num_states: usize) -> Vec<Self>
Available on non-CUDA only.
pub fn initialize_states(seed: u64, num_states: usize) -> Vec<Self>
Initializes multiple RNG states such that each state corresponds to a subsequence
separated by 2**64 steps from eachother in the main sequence. This ensures that as long as
no state requests more than 2**64 random numbers, the states are guaranteed to be fully independent.